@@ -64,7 +64,7 @@ void SessionModel::loadDir(const QString &path, SessionType type)
         QFile inputFile(dir.absoluteFilePath(session));
         if (!inputFile.open(QIODevice::ReadOnly))
             continue;
-        SessionPtr si { new Session { session.chopped(strlen(".desktop")), QString(), QString(), QString() } };
+        SessionPtr si { new Session { session, "", "", "" } };
         bool isHidden = false;
         QString current_section;
         QTextStream in(&inputFile);
@@ -117,6 +117,7 @@ QHash<int, QByteArray> SessionModel::roleNames() const {
 }
 
 int SessionModel::rowCount(const QModelIndex &parent) const {
+    Q_UNUSED(parent);
     return d->sessions.length();
 }
 
